Version History
===

### 1.3 
* Python 3 compatibility
* Use Babel's js parser 

### 1.2.2
* add uniform support for `v-*` and `:*` attributes

### 1.2.1
* add support for :text attributes
* some refactoring

### 1.2

* Add v-html directive

### 1.1

* Fix Py3 compatibility
* Refactor setup.py

### 1.0 

* First public release
